@@ -85,7 +85,11 @@ where
             return;
         }
 
-        if self.ctx.is_delete_arg || self.ctx.is_update_arg || self.ctx.is_lhs_of_assign {
+        if self.ctx.is_delete_arg
+            || self.ctx.is_update_arg
+            || self.ctx.is_lhs_of_assign
+            || self.ctx.in_with_stmt
+        {
             return;
         }
 
